@@ -1,4 +1,4 @@
-plotLongCART<- function(x, uniform = FALSE, branch = 1, nspace,
+plotLongCART<- function(x, uniform = FALSE, branch = 1, nspace=branch,
      margin = 0, minbranch = 0.3, ...){
 	plot(x=x, uniform = uniform, branch = branch, compress = FALSE,
            nspace=nspace, margin = margin, minbranch = minbranch, ...)
